@@ -1,4 +1,6 @@
+import json
 import logging
+from datetime import datetime, date
 from flask import Blueprint, session, flash, render_template, url_for, abort
 from ._compat import as_unicode
 from .forms import GeneralModelConverter
@@ -790,6 +792,10 @@ class BaseCRUDView(BaseModelView):
         joined_filters = filters.get_joined_filters(self._base_filters)
         count, lst = self.datamodel.query(joined_filters, order_column, order_direction, page=page, page_size=page_size)
         pks = self.datamodel.get_keys(lst)
+
+        # serialize composite pks
+        pks = [self._serialize_pk_if_composite(pk) for pk in pks]
+
         widgets['list'] = self.list_widget(label_columns=self.label_columns,
                                            include_columns=self.list_columns,
                                            value_columns=self.datamodel.get_values(lst, self.list_columns),
@@ -910,6 +916,7 @@ class BaseCRUDView(BaseModelView):
         if request.method == 'POST':
             self._fill_form_exclude_cols(exclude_cols, form)
             if form.validate():
+                self.process_form(form, True)
                 item = self.datamodel.obj()
                 form.populate_obj(item)
 
@@ -954,6 +961,7 @@ class BaseCRUDView(BaseModelView):
             # trick to pass unique validation
             form._id = pk
             if form.validate():
+                self.process_form(form, False)
                 form.populate_obj(item)
                 try:
                     self.pre_update(item)
@@ -970,6 +978,9 @@ class BaseCRUDView(BaseModelView):
         else:
             # Only force form refresh for select cascade events
             form = self.edit_form.refresh(obj=item)
+            # Perform additional actions to pre-fill the edit form.
+            self.prefill_form(form, pk)
+
         widgets = self._get_edit_widget(form=form, exclude_cols=exclude_cols)
         widgets = self._get_related_views_widgets(item, filters={},
                                                   orders=orders, pages=pages, page_sizes=page_sizes, widgets=widgets)
@@ -1004,6 +1015,45 @@ class BaseCRUDView(BaseModelView):
     ------------------------------------------------
     """
 
+    def _serialize_pk_if_composite(self, pk):
+        def date_serializer(obj):
+            if isinstance(obj, datetime):
+                return {
+                    "_type": "datetime",
+                    "value": obj.isoformat()
+                }
+            elif isinstance(obj, date):
+                return {
+                    "_type": "date",
+                    "value": obj.isoformat()
+                }
+
+        if self.datamodel.is_pk_composite():
+            try:
+                pk = json.dumps(pk, default=date_serializer)
+            except:
+                pass
+        return pk
+
+    def _deserialize_pk_if_composite(self, pk):
+        def date_deserializer(obj):
+            if '_type' not in obj:
+                return obj
+
+            from dateutil import parser
+            if obj['_type'] == 'datetime':
+                return parser.parse(obj['value'])
+            elif obj['_type'] == 'date':
+                return parser.parse(obj['value']).date()
+            return obj
+
+        if self.datamodel.is_pk_composite():
+            try:
+                pk = json.loads(pk, object_hook=date_deserializer)
+            except:
+                pass
+        return pk
+
     def _fill_form_exclude_cols(self, exclude_cols, form):
         """
             fill the form with the suppressed cols, generated from exclude_cols
@@ -1015,6 +1065,40 @@ class BaseCRUDView(BaseModelView):
                 field = getattr(form, filter_key)
                 field.data = rel_obj
 
+    def prefill_form(self, form, pk):
+        """
+            Override this, will be called only if the current action is rendering
+            an edit form (a GET request), and is used to perform additional action to
+            prefill the form.
+
+            This is useful when you have added custom fields that depend on the
+            database contents. Fields that were added by name of a normal column
+            or relationship should work out of the box.
+
+            example::
+
+                def prefill_form(self, form, pk):
+                    if form.email.data:
+                        form.email_confirmation.data = form.email.data
+        """
+        pass
+
+    def process_form(self, form, is_created):
+        """
+            Override this, will be called only if the current action is submitting
+            a create/edit form (a POST request), and is used to perform additional
+            action before the form is used to populate the item.
+
+            By default does nothing.
+
+            example::
+
+                def process_form(self, form, is_created):
+                    if not form.owner:
+                        form.owner.data = 'n/a'
+        """
+        pass
+
     def pre_update(self, item):
         """
             Override this, this method is called before the update takes place.
